## R code: playing with eBird species totals for NV counties

## Data from
#   https://en.wikipedia.org/wiki/List_of_counties_in_Nevada
#   https://ebird.org/region/US-NV/subregions

# Open Excel file
library(readxl)
ebdat <- as.data.frame(read_xlsx("eBird-NV-counties-species.xlsx", sheet = 1))
str(ebdat)
ebdat

# remove state totals
NVtotal = 494 # NV statewide species total
ebdat <- ebdat[-nrow(ebdat),] 
ebdat

ebdat

# plot the data
par(mfrow=c(2,2))
scatter.smooth(ebdat$Area, ebdat$BirdSpecies, 
               xlab="County Area (sq-mi)", ylab="Bird Species",
               lpars = c(col="red", lwd=2), pch=20)
scatter.smooth(ebdat$Population, ebdat$BirdSpecies, 
               xlab="Population Size", ylab="Bird Species",
               lpars = c(col="red", lwd=2), pch=20)
scatter.smooth(ebdat$Population[-3], ebdat$BirdSpecies[-3], 
               xlab="Population Size", ylab="Bird Species",
               lpars = c(col="red", lwd=2), pch=20, main="W/o Clark")
scatter.smooth(ebdat$Population[-c(3,16)], ebdat$BirdSpecies[-c(3,16)], 
               xlab="Population Size", ylab="Bird Species",
               lpars = c(col="red", lwd=2), pch=20, main="W/o Clark, Washoe")

# Some regressions
fitA  = lm(BirdSpecies ~ Area, data=ebdat)
fitPA = lm(BirdSpecies ~ Population + Area, data=ebdat)
fitPxA = lm(BirdSpecies ~ Population * Area, data=ebdat)
anova(fitA,fitPA,fitPxA)
summary(fitPA)
summary(fitPxA)
anova(fitPA)

par(mfrow=c(2,2))
plot(fitPA)

# Without Clark, Washoe...
ebdat2 = ebdat[-c(3,16),]
fitPA2 = lm(BirdSpecies ~ Population + Area, data=ebdat2)
fitPxA2 = lm(BirdSpecies ~ Population * Area, data=ebdat2)
summary(fitPxA2)
summary(fitPA2)
anova(fitPA2)

par(mfrow=c(2,2))
plot(fitPA2)

